@@ -31,6 +31,8 @@ def _gen_pkce_pair() -> tuple[str, str]:
 
 def _validate_redirect(url: str, allow_hosts: list[str], *, require_https: bool) -> None:
     p = urlparse(url)
+    if not p.netloc:
+        return
     host_port = p.hostname.lower() + (f":{p.port}" if p.port else "")
     allowed = {h.lower() for h in allow_hosts}
     if host_port not in allowed and p.hostname.lower() not in allowed:
@@ -62,6 +64,19 @@ def _coerce_expires_at(token: dict | None) -> datetime | None:
     return None
 
 
+def _cookie_name(st) -> str:
+    name = st.session_cookie_name
+    if st.session_cookie_secure and not st.session_cookie_domain and not name.startswith("__Host-"):
+        name = "__Host-" + name
+    return name
+
+
+def _cookie_domain(st):
+    # IMPORTANT: return None for localhost/dev instead of "" or invalid host
+    d = getattr(st, "session_cookie_domain", None)
+    return d or None
+
+
 def oauth_router_with_backend(
     user_model: type,
     auth_backend: AuthenticationBackend,
@@ -170,6 +185,7 @@ def oauth_router_with_backend(
         email: str | None = None
         full_name: str | None = None
         provider_user_id: str | None = None
+        email_verified: bool | None = None
 
         if kind == "oidc":
             claims: dict[str, Any] = {}
@@ -194,6 +210,7 @@ def oauth_router_with_backend(
 
             email = claims.get("email")
             full_name = claims.get("name") or claims.get("preferred_username")
+            email_verified = bool(claims.get("email_verified", True))
 
             provider_user_id = None
             sub_or_oid = claims.get("sub") or claims.get("oid")
@@ -211,13 +228,16 @@ def oauth_router_with_backend(
 
         elif kind == "github":
             u = (await client.get("user", token=token)).json()
+            emails_resp = (await client.get("user/emails", token=token)).json()
+            primary = next((e for e in emails_resp if e.get("primary") and e.get("verified")), None)
+            if not primary:
+                raise HTTPException(400, "unverified_email")
+            email = primary["email"]
+            email_verified = True
+            full_name = u.get("name") or u.get("login")
             provider_user_id = (
                 str(u.get("id")) if isinstance(u, dict) and u.get("id") is not None else None
             )
-            emails_resp = (await client.get("user/emails", token=token)).json()
-            primary = next((e for e in emails_resp if e.get("primary") and e.get("verified")), None)
-            email = (primary or (emails_resp[0] if emails_resp else {})).get("email")
-            full_name = u.get("name") or u.get("login")
 
         elif kind == "linkedin":
             me = (await client.get("me", token=token)).json()
@@ -237,10 +257,15 @@ def oauth_router_with_backend(
             first = next(iter(lf), None)
             last = next(iter(ll), None)
             full_name = " ".join([x for x in [first, last] if x])
+            email_verified = True
 
         else:
             raise HTTPException(400, "Unsupported provider kind")
 
+        if email_verified is False:
+            # Stop here—don’t create/link accounts on unverified addresses.
+            raise HTTPException(400, "unverified_email")
+
         if not email:
             raise HTTPException(400, "No email from provider")
 
@@ -260,24 +285,8 @@ def oauth_router_with_backend(
                 .scalars()
                 .first()
             )
-
-            user = None
-            existing_link = None
-            if provider_account_model is not None and provider_user_id:
-                existing_link = (
-                    (
-                        await session.execute(
-                            select(provider_account_model).filter_by(
-                                provider=provider,
-                                provider_account_id=provider_user_id,
-                            )
-                        )
-                    )
-                    .scalars()
-                    .first()
-                )
-                if existing_link:
-                    user = await session.get(user_model, existing_link.user_id)
+            if existing_link:
+                user = await session.get(user_model, existing_link.user_id)
 
         # --- Fallback: resolve/create by email (previous logic) --------------
         if user is None:
@@ -409,13 +418,8 @@ def oauth_router_with_backend(
             )
         resp = RedirectResponse(url=redirect_url, status_code=status.HTTP_302_FOUND)
 
-        name = st.session_cookie_name
-        if (
-            st.session_cookie_secure
-            and not st.session_cookie_domain
-            and st.session_cookie_name[:7] != "__Host-"
-        ):
-            name = "__Host-" + st.session_cookie_name
+        name = _cookie_name(st)
+        domain = _cookie_domain(st)
 
         resp.set_cookie(
             key=name,
@@ -423,8 +427,37 @@ def oauth_router_with_backend(
             max_age=st.session_cookie_max_age_seconds,
             httponly=True,
             secure=bool(st.session_cookie_secure),
-            samesite=same_site_lit,  # "none" only if secure
-            domain=st.session_cookie_domain,  # must be None for __Host-
+            samesite=same_site_lit,
+            domain=domain,
+            path="/",
+        )
+        return resp
+
+    @router.post("/refresh")
+    async def refresh(request: Request):
+        st = get_auth_settings()
+        name = _cookie_name(st)
+        raw = request.cookies.get(name)
+        if not raw:
+            raise HTTPException(401, "missing_token")
+
+        strategy = auth_backend.get_strategy()
+        try:
+            user = await strategy.read_token(raw, None)  # contextless
+        except Exception:
+            raise HTTPException(401, "invalid_token")
+
+        new_token = await strategy.write_token(user)
+
+        resp = Response(status_code=204)
+        resp.set_cookie(
+            key=name,
+            value=new_token,
+            max_age=st.session_cookie_max_age_seconds,
+            httponly=True,
+            secure=bool(st.session_cookie_secure),
+            samesite=str(st.session_cookie_samesite).lower(),
+            domain=_cookie_domain(st),
             path="/",
         )
         return resp
@@ -439,16 +472,13 @@ def oauth_router_with_backend(
                 request.session.pop(k, None)
 
         # delete auth cookie
-        name = st.session_cookie_name
-        if (
-            st.session_cookie_secure
-            and not st.session_cookie_domain
-            and not name.startswith("__Host-")
-        ):
-            name = "__Host-" + name
-
+        name = _cookie_name(st)
         resp = Response(status_code=204)
-        resp.delete_cookie(key=name, domain=st.session_cookie_domain, path="/")
+        resp.delete_cookie(
+            key=name,
+            domain=_cookie_domain(st),
+            path="/",
+        )
         return resp
 
     return router
