@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 
 from fastapi import Response, status
@@ -6,6 +8,8 @@ from svc_infra.api.fastapi import DualAPIRouter
 
 router = DualAPIRouter()
 
+ROUTER_TAG = "health"
+
 
 @router.get("/ping", status_code=status.HTTP_200_OK)
 def ping():
